@@ -1,21 +1,24 @@
-from nonebot.adapters.onebot.v11 import NoticeEvent,Bot,MessageEvent,Message,MessageSegment
+from nonebot.adapters.onebot.v11 import NoticeEvent,Bot,MessageEvent,Message,MessageSegment,GroupMessageEvent
 from nonebot.params import CommandArg,ArgPlainText,RegexGroup
 from nonebot.matcher import Matcher
+from nonebot.typing import T_State
 from typing import Tuple
 from time import sleep
 from .config import *
 from .utils import *
 from .command import *
+from .l4d2_image.download import url_to_byte
 from nonebot.plugin import PluginMetadata
 from .l4d2_data import sq_L4D2
 from nonebot import get_driver
+import tempfile
 driver = get_driver()
 
 
-__version__ = "0.1.5"
+__version__ = "0.2.0"
 __plugin_meta__ = PluginMetadata(
-    name="求生服务器操作",
-    description='群内对服务器的简单操作',
+    name="求生之路小助手",
+    description='群内对有关求生之路的查询和操作',
     usage='求生服务器操作指令',
     extra={
         "version": __version__,
@@ -78,9 +81,9 @@ async def _(bot:Bot,event: MessageEvent):
     logger.info("获取文件列表成功")
     mes = "当前服务器下有以下vpk文件"
     msg = mes_list(mes,name_vpk).replace(" ","")
-    if l4_image:
+    try:
         await find_vpk.finish(MessageSegment.image(text_to_png(msg)))
-    else:
+    except OSError:
         await find_vpk.finish(msg)
 
 @del_vpk.handle()
@@ -121,20 +124,7 @@ async def _(event:MessageEvent,args:Message = CommandArg()):
     if type(msg)==str:
         await anne_player.finish(msg)
     else:
-        await anne_player.finish(MessageSegment.image(msg))
-        
-@anne_server.handle()
-async def _():
-    await anne_server.send('正在查询，方式是谷歌浏览器')
-    msg = anne_servers()
-    if len(msg)==0:
-        await anne_server.finish('服务器超市了')
-    else:
-        if l4_image:
-            await find_vpk.finish(MessageSegment.image(text_to_png(msg)))
-        else:
-            await anne_server.finish(msg)
-    
+        await anne_player.finish(MessageSegment.image(msg)) 
     
 @anne_bind.handle()
 async def _(event:MessageEvent,args:Message = CommandArg()):
@@ -144,7 +134,7 @@ async def _(event:MessageEvent,args:Message = CommandArg()):
         await anne_bind.finish("虚空绑定?")
     usr_id = str(event.user_id)
     nickname = event.sender.card or event.sender.nickname
-    msg = bind_steam(usr_id,tag,nickname)
+    msg = await bind_steam(usr_id,tag,nickname)
     await anne_bind.finish(msg)
 
 @del_bind.handle()
@@ -176,10 +166,93 @@ async def _(matcher:Matcher,args:Message = CommandArg()):
 @queries.got("ip",prompt="请输入ip,格式如中括号内【127.0.0.1】【114.51.49.19:1810】")
 async def _(tag:str = ArgPlainText("ip")):
     ip = split_maohao(tag)
-    msg = queries_server(ip)
+    msg = await queries_server(ip)
     await queries.finish(msg)
     
+
+@add_queries.handle()
+async def _(event:GroupMessageEvent,args:Message = CommandArg()):
+    msg = args.extract_plain_text()
+    if len(msg)==0:
+        await add_queries.finish('请在该指令后加入参数，例如【114.51.49.19:1810】')
+    [host,port] = split_maohao(msg)
+    group_id = event.group_id
+    msg = await add_ip(group_id,host,port)
+    await add_queries.finish(msg)
+
+@del_queries.handle()
+async def _(event:GroupMessageEvent,matcher:Matcher,args:Message = CommandArg()):
+    msg = args.extract_plain_text()
+    if not msg.isdigit():
+        await del_queries.finish('请输入正确的序号数字')
+    group_id = event.group_id
+    msg = await del_ip(group_id,msg)
+    await del_queries.finish(msg)
+   
+@show_queries.handle()
+async def _(event:GroupMessageEvent):
+    group_id = event.group_id
+    msg = await show_ip(group_id)
+    if type(msg) == str:
+        await show_queries.finish(msg)
+    else:
+        await show_queries.finish(MessageSegment.image(msg))
+
+@join_server.handle()
+async def _(args:Message = CommandArg()):
+    msg = args.extract_plain_text()
+    url = await get_number_url(msg)
+    await join_server.finish(url)
     
+        
+@up_workshop.handle()
+async def _(matcher:Matcher,args:Message = CommandArg()):
+    msg = args.extract_plain_text()
+    if msg:
+        matcher.set_arg("ip",args)
+    
+@up_workshop.got("ip",prompt="请输入创意工坊网址或者物品id")
+async def _(matcher:Matcher,state:T_State,tag:str = ArgPlainText("ip")):
+    msg = await workshop_msg(tag)
+    if not msg:
+        await up_workshop.finish('没有这个物品捏')
+    pic = await url_to_byte(msg['图片地址'])
+    message = ''
+    for item,value in msg.items():
+        if item in ['图片地址','下载地址']:
+            continue
+        message += item + ':' + value + '\n'
+    state['dic'] = msg
+    await up_workshop.send(MessageSegment.image(pic) + Message(message))
+    
+@up_workshop.got("is_sure",prompt='如果需要上传，请发送 "yes"')    
+async def _(matcher: Matcher,bot:Bot,event:GroupMessageEvent,state:T_State):
+    is_sure = str(state["is_sure"])
+    data_dict:dict = state['dic']
+    logger.info('开始上传')
+    data_file = await url_to_byte(data_dict['下载地址'])
+    file_name = data_dict['名字']+ '.vpk'
+    await up_workshop.send('获取地址成功，尝试上传')
+    if is_sure == 'yes':
+        await upload_file(bot, event, data_file, file_name)
+    else:
+        await matcher.finish('已取消上传')
+    
+    
+async def upload_file(bot: Bot, event: MessageEvent, file_data: bytes, filename: str):
+    with tempfile.NamedTemporaryFile("wb+") as f:
+        f.write(file_data)
+        if isinstance(event, GroupMessageEvent):
+            await bot.call_api(
+                "upload_group_file", group_id=event.group_id, file=f.name, name=filename
+            )
+        else:
+            await bot.call_api(
+                "upload_private_file", user_id=event.user_id, file=f.name, name=filename
+            )
+
+
 @driver.on_shutdown
 async def close_db():
+    """关闭数据库"""
     sq_L4D2._close()
\ No newline at end of file
