@@ -10,13 +10,11 @@ except:
 from pathlib import Path
 from .txt_to_img import txt_to_img
 from .config import *
-# from .l4d2_anne.__init__ import *
 from .l4d2_anne import write_player,del_player,anne_messgae
-from .chrome import get_anne_server
 from .l4d2_server.rcon import read_server_cfg_rcon,rcon_server
-from .l4d2_image.draw_user_info import draw_user_info_img
-from .l4d2_queries import queries
-
+from .l4d2_queries import queries,player_queries
+from .l4d2_queries.qqgroup import *
+from .l4d2_server.workshop import workshop_to_dict
 
 
 def get_file(url,down_file):
@@ -113,12 +111,12 @@ def open_packet(name,down_file):
         mes ='vpk文件已下载'
     return mes
 
-def solve(s):
+def solve(msg:str):
     """删除str最后一行"""
-    s = s.split('\n', 1)[-1]
-    if s.find('\n') == -1:
-        return ''
-    return s.rsplit('\n', 1)[0]
+    lines = msg.splitlines()
+    lines.pop()
+    return '\n'.join(lines)
+
 
 async def search_anne(name:str,usr_id:str):
     msg = await anne_messgae(name,usr_id)
@@ -127,9 +125,9 @@ async def search_anne(name:str,usr_id:str):
     return msg
     
 
-def bind_steam(id:str,msg:str,nickname:str):
+async def bind_steam(id:str,msg:str,nickname:str):
     """绑定qq-steam"""
-    return write_player(id,msg,nickname)
+    return await write_player(id,msg,nickname)
 
 def name_exist(id:str):
     """删除绑定信息"""
@@ -151,10 +149,6 @@ async def get_message_at(data: str) -> list:
     except Exception:
         return []
     
-def anne_servers():
-    mes = get_anne_server()
-    mes = solve(mes)
-    return mes
 
 def at_to_usrid(usr_id,at):
     """at对象变qqid否则返回usr_id"""
@@ -182,10 +176,59 @@ async def command_server(msg:str):
 def split_maohao(msg:str) -> list:
     """分割大小写冒号"""
     msg:list = re.split(":|：",msg.strip())
-    msg[-1] = msg[-1] if len(msg[-1])!=0 else '20715'  
-    return msg
+    mse = [msg[0],msg[-1]] if msg[0] != msg[-1] else [msg[0],20715]
+    return mse
 
-def queries_server(msg:list) -> str:
+async def queries_server(msg:list) -> str:
     """查询ip返回信息"""
     print(msg)
-    return queries(msg[0],msg[1])
\ No newline at end of file
+    ip = msg[0]
+    port = msg[1]
+    msgs = await player_queries(ip,port)
+    msgs += await queries(ip,port) 
+    return msgs
+
+async def add_ip(group_id,host,port):
+    """先查找是否存在，如果不存在则创建"""
+    return await bind_group_ip(group_id,host,port)
+
+async def del_ip(group_id,number):
+    """删除群ip"""
+    return await del_group_ip(group_id,number)
+
+async def show_ip(group_id):
+    """先查找群ip，再根据群ip返回"""
+    data_list = await get_qqgroup_ip_msg(group_id)
+    logger.info(data_list)
+    if len(data_list) == 0 :
+        return "本群没有订阅"
+    msg = await qq_ip_queries_pic(data_list)
+    if type(msg) == str:
+        msg = solve(msg)
+    return  msg
+
+async def get_number_url(number):
+    'steam://connect/AGNES.DIGITAL.LINE.PM:40001'
+    ip = await get_server_ip(number)
+    if not ip:
+        return '该序号不存在'
+    url = f'steam://connect/{ip}'
+    return url
+
+async def workshop_msg(msg:str):
+    """url变成id，拼接post请求"""
+    if msg.startswith('https://steamcommunity.com/sharedfiles/filedetails/?id'):
+        try:
+            msg = msg.split('&')[0]
+        except:
+            pass
+        msg = msg.replace('https://steamcommunity.com/sharedfiles/filedetails/?id=','')
+    if msg.isdigit():
+        data:dict = await workshop_to_dict(msg)
+        return data
+    else:
+        return None
+    
+async def save_file(file:bytes,path_name):
+    with open(path_name,'w') as files:
+        files.write(file)
\ No newline at end of file
